#!/usr/bin/env ruby
# -*- coding: utf-8 -*-
# alone : web application framework for small embedded systems.
#               Copyright (c) 2009-2010 Inas Co Ltd. All Rights Reserved.
#
# This file is destributed under BSD License. Please read the COPYRIGHT file.
#


##
# リレーショナルデータベースラッパー スーパクラス
#
class AlRdbw

  #@return [Hash<AlRdbw>] Rdbwオブジェクトの配列
  @@rdbw_objects = {}

  #@return [Object] デフォルトRdbwオブジェクト
  @@default_rdbw_object = nil

  #@return [String]  接続文字列
  attr_reader :conn_str

  #@return [Object] データベースハンドル
  attr_reader :handle
  
  #@return [Boolean] トランザクション中かを示すフラグ
  attr_reader :flag_transaction


  ##
  # DB wrapper オブジェクトを得る。
  #
  #@param [String] conn_str  接続文字列
  #@return [AlRdbw]     DBWrapperオブジェクト
  #@note
  # 名前とは裏腹に、DBSとの接続は開始しない。
  # 接続は、オブジェクトに対しopen_connection()メソッドで意識的に行うか、
  # あるいは、ヘルパーメソッドを使ったときに自動的に行われる。
  #
  def self.connect( conn_str = nil )

    # 既に対象の接続オブジェクトがあれば、それを返す。
    obj = conn_str ? @@rdbw_objects[ conn_str.hash ] : @@default_rdbw_object
    return obj  if obj

    raise "Connection string is missing."  if ! conn_str

    # オブジェクトの生成と保存
    obj = self.new( conn_str )
    @@default_rdbw_object ||= obj
    @@rdbw_objects[ conn_str.hash ] = obj
    return obj
  end


  ##
  # constractor
  #
  #@note
  # ユーザプログラムからは直接使わない。
  # オブジェクトの生成は、connect()メソッドを使って行う。
  #
  def initialize( conn_str )
    # AlRdbwは、バーチャルクラス扱いなので生成をランタイムエラーにしておく。
    raise "Need create in subclass" if self.class == AlRdbw

    @conn_str = conn_str
    @handle = nil
    @flag_transaction = false
  end


  ##
  # RDBSとの接続ハンドルを得る
  #
  #@return [Object] handle
  #@note
  # 接続がまだ行われていなければ、自動的に接続を開始する。
  #
  def get_handle()
    if ! @handle
      open_connection()
    end
    return @handle
  end


  ##
  # トランザクション中か？
  #
  #@return [Boolean]    はい／いいえ
  #
  def transaction_active?()
    return @flag_transaction
  end

end
